@@ -220,7 +220,7 @@ setMethod("geno", c("VCF", "character"),
 setReplaceMethod("geno", c("VCF", "missing", "SimpleList"),
     function(x, i, ..., value)
 {
-    assays(x) <- value
+    assays(x, withDimnames=FALSE) <- value
     .valid.VCFHeadervsVCF.fields(x, geno)
     x
 })
@@ -228,7 +228,7 @@ setReplaceMethod("geno", c("VCF", "missing", "SimpleList"),
 setReplaceMethod("geno", c("VCF", "character", "matrix"),
     function(x, i, ..., value)
 {
-    assay(x, i) <- value
+    assay(x, i, withDimnames=FALSE) <- value
     .valid.VCFHeadervsVCF.fields(x, geno)
     x
 })
@@ -236,7 +236,7 @@ setReplaceMethod("geno", c("VCF", "character", "matrix"),
 setReplaceMethod("geno", c("VCF", "numeric", "matrix"),
     function(x, i, ..., value)
 {
-    assay(x, i) <- value
+    assay(x, i, withDimnames=FALSE) <- value
     .valid.VCFHeadervsVCF.fields(x, geno)
     x
 })
@@ -244,7 +244,7 @@ setReplaceMethod("geno", c("VCF", "numeric", "matrix"),
 setReplaceMethod("geno", c("VCF", "missing", "matrix"),
     function(x, i, ..., value)
 {
-    assay(x) <- value
+    assay(x, withDimnames=FALSE) <- value
     .valid.VCFHeadervsVCF.fields(x, geno)
     x
 })
@@ -296,6 +296,10 @@ setMethod("vcfFields", "VCF",
 ### Subsetting and combining
 ###
 
+setMethod(vertical_slot_names, "VCF", function(x) {
+    c("fixed", "info", callNextMethod())
+})
+
 setMethod("[", c("VCF", "ANY", "ANY"),
     function(x, i, j, ..., drop=TRUE)
 {
@@ -518,7 +522,7 @@ setMethod(show, "VCF",
         lx <- length(x)
         nc <- ncol(mcols(x))
         nms <- names(mcols(x))
-        cat(margin, class(x), " with ",
+        cat(margin, classNameForDisplay(x), " with ",
             nc, " metadata ", ifelse(nc == 1L, "column", "columns"),
             ": ", paste0(nms, collapse=", "), "\n", sep="")
     }
@@ -526,7 +530,7 @@ setMethod(show, "VCF",
     {
         nc <- ncol(x)
         nms <- names(x)
-        cat(margin, class(x), " with ",
+        cat(margin, classNameForDisplay(x), " with ",
             nc, ifelse(nc == 1, " column", " columns"),
             ": ", prettydescr(paste0(nms, collapse=", ")), "\n", sep="")
     }
@@ -534,11 +538,11 @@ setMethod(show, "VCF",
     {
         lo <- length(x)
         nms <- names(x)
-        cat(margin, class(x), " of length ", lo, 
+        cat(margin, classNameForDisplay(x), " of length ", lo, 
             ": ", prettydescr(paste0(nms, collapse=", ")), "\n", sep="")
     }
     margin <- "  "
-    cat("class:", class(object), "\n")
+    cat("class:", classNameForDisplay(object), "\n")
     cat("dim:", dim(object), "\n")
     cat("rowRanges(vcf):\n")
     printSmallGRanges(rowRanges(object), margin=margin)
